==> ejc-purchase-impl-3.0.0-20250424.070655-4-sources.jar: com/ejianc/business/purchase/bean/ThreeSubPlanDetailEntity.java <==
package com.ejianc.business.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 三个月滚动分包服务计划-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchase_three_sub_plan_detail")
public class ThreeSubPlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="purchase_type")
    private String purchaseType; // 采购类别
    @TableField(value="purchase_way")
    private String purchaseWay; // 采购方式
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    @TableField(value="sub_scope")
    private String subScope; // 分包范围
    @TableField(value="valuation_model")
    private String valuationModel; // 计价模式
    @TableField(value="budget_mny")
    private BigDecimal budgetMny; // 预算金额(万元)
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 预计成本金额(万元)
    @TableField(value="purchase_date")
    private Date purchaseDate; // 预计采购时间
    @TableField(value="enter_date")
    private Date enterDate; // 计划进场时间
    @TableField(value="pay_scale")
    private String payScale; // 付款比例
    @TableField(value="pay_way")
    private String payWay; // 支付方式
    @TableField(value="certification")
    private String certification; // 分包资质要求
    @TableField(value="duration")
    private Integer duration; // 工期/供货期(月)
    @TableField(value="section_division")
    private String sectionDivision; // 标段划分
    @TableField(value="unit_info")
    private String unitInfo; // 寻源单位信息
    @TableField(value="material_num")
    private String materialNum; // 物资数量
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getPurchaseWay() {
        return purchaseWay;
    }

    public void setPurchaseWay(String purchaseWay) {
        this.purchaseWay = purchaseWay;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSubScope() {
        return subScope;
    }

    public void setSubScope(String subScope) {
        this.subScope = subScope;
    }
    public String getValuationModel() {
        return valuationModel;
    }

    public void setValuationModel(String valuationModel) {
        this.valuationModel = valuationModel;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public Date getPurchaseDate() {
        return purchaseDate;
    }

    public void setPurchaseDate(Date purchaseDate) {
        this.purchaseDate = purchaseDate;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public String getPayScale() {
        return payScale;
    }

    public void setPayScale(String payScale) {
        this.payScale = payScale;
    }
    public String getPayWay() {
        return payWay;
    }

    public void setPayWay(String payWay) {
        this.payWay = payWay;
    }
    public String getCertification() {
        return certification;
    }

    public void setCertification(String certification) {
        this.certification = certification;
    }
    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }
    public String getSectionDivision() {
        return sectionDivision;
    }

    public void setSectionDivision(String sectionDivision) {
        this.sectionDivision = sectionDivision;
    }
    public String getUnitInfo() {
        return unitInfo;
    }

    public void setUnitInfo(String unitInfo) {
        this.unitInfo = unitInfo;
    }
    public String getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(String materialNum) {
        this.materialNum = materialNum;
    }
    
}

==> ejc-purchase-impl-3.0.0-20250424.091614-5-sources.jar: com/ejianc/business/purchase/bean/ThreeSubPlanDetailEntity.java <==
package com.ejianc.business.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 三个月滚动分包服务计划-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchase_three_sub_plan_detail")
public class ThreeSubPlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="purchase_type")
    private String purchaseType; // 采购类别
    @TableField(value="purchase_way")
    private String purchaseWay; // 采购方式
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    @TableField(value="sub_scope")
    private String subScope; // 分包范围
    @TableField(value="valuation_model")
    private String valuationModel; // 计价模式
    @TableField(value="budget_mny")
    private BigDecimal budgetMny; // 预算金额
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 预计成本金额
    @TableField(value="purchase_date")
    private Date purchaseDate; // 预计采购时间
    @TableField(value="enter_date")
    private Date enterDate; // 计划进场时间
    @TableField(value="pay_scale")
    private String payScale; // 付款比例
    @TableField(value="pay_way")
    private String payWay; // 支付方式
    @TableField(value="certification")
    private String certification; // 分包资质要求
    @TableField(value="duration")
    private Integer duration; // 工期/供货期(月)
    @TableField(value="section_division")
    private String sectionDivision; // 标段划分
    @TableField(value="unit_info")
    private String unitInfo; // 寻源单位信息
    @TableField(value="material_num")
    private String materialNum; // 物资数量
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getPurchaseWay() {
        return purchaseWay;
    }

    public void setPurchaseWay(String purchaseWay) {
        this.purchaseWay = purchaseWay;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSubScope() {
        return subScope;
    }

    public void setSubScope(String subScope) {
        this.subScope = subScope;
    }
    public String getValuationModel() {
        return valuationModel;
    }

    public void setValuationModel(String valuationModel) {
        this.valuationModel = valuationModel;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public Date getPurchaseDate() {
        return purchaseDate;
    }

    public void setPurchaseDate(Date purchaseDate) {
        this.purchaseDate = purchaseDate;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public String getPayScale() {
        return payScale;
    }

    public void setPayScale(String payScale) {
        this.payScale = payScale;
    }
    public String getPayWay() {
        return payWay;
    }

    public void setPayWay(String payWay) {
        this.payWay = payWay;
    }
    public String getCertification() {
        return certification;
    }

    public void setCertification(String certification) {
        this.certification = certification;
    }
    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }
    public String getSectionDivision() {
        return sectionDivision;
    }

    public void setSectionDivision(String sectionDivision) {
        this.sectionDivision = sectionDivision;
    }
    public String getUnitInfo() {
        return unitInfo;
    }

    public void setUnitInfo(String unitInfo) {
        this.unitInfo = unitInfo;
    }
    public String getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(String materialNum) {
        this.materialNum = materialNum;
    }
    
}
